@@ -55,9 +55,11 @@ push @{ config->{engines}->{netdisco_template_toolkit}->{INCLUDE_PATH} },
 
 # any template paths in deployment.yml (should override plugins)
 if (setting('template_paths') and ref [] eq ref setting('template_paths')) {
-    push @{setting('template_paths')},
-         dir(($ENV{NETDISCO_HOME} || $ENV{HOME}), 'nd-site-local', 'share')->stringify
-      if (setting('site_local_files'));
+    if (setting('site_local_files')) {
+      push @{setting('template_paths')},
+         dir(($ENV{NETDISCO_HOME} || $ENV{HOME}), 'nd-site-local', 'share')->stringify,
+         dir(($ENV{NETDISCO_HOME} || $ENV{HOME}), 'nd-site-local', 'share', 'views')->stringify;
+    }
     unshift @{ config->{engines}->{netdisco_template_toolkit}->{INCLUDE_PATH} },
       @{setting('template_paths')};
 }
